| Title: | Interactive Document for Working with Naive Bayes Classification |
|---|---|
| Description: | An interactive document on the topic of naive Bayes classification analysis using 'rmarkdown' and 'shiny' packages. Runtime examples are provided in the package function as well as at <https://kartikeyab.shinyapps.io/NBShiny/>. |
| Authors: | Kartikeya Bolar |
| Maintainer: | Kartikeya Bolar <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.0 |
| Built: | 2026-05-28 10:30:28 UTC |
| Source: | https://github.com/cran/NBShiny2 |
NBShiny2() loads interactive user interface built using R 'shiny'.
NBShiny2()NBShiny2()
Start NBShiny2
The interactive user interface is to provide an easy way for naive bayesian classification analysis and downloading relevant plot.
Nothing
if(interactive()){ library(rmarkdown) NBShiny2() }if(interactive()){ library(rmarkdown) NBShiny2() }